netapp_ontap.models.data_engine_event_job API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_event_job`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineEventJobSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineEventJob object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `name: str GET`

    The name of the job.

    Example: workspace create

  `state: str GET`

    The state of the data engine job:

    - queued - The job is queued for execution.
    - running - The job is currently in execution.
    - success - The job has been completed successfully.
    - failure - The job has failed.

    Valid choices:

    - queued
    - running
    - success
    - failure
  `type: str GET`

    The type of the job.

    Valid choices:

    - workspace_create
    - workspace_update
    - workspace_delete
    - workspace_refresh
    - workspace_content_processing
    - workspace_versioning
    - data_collection_update
    - data_collection_delete
    - data_collection_refresh
    - data_collection_content_processing
    - data_source_create
    - data_source_update
    - data_source_delete
    - data_source_refresh
    - policy_enforcement
    - cleanup
    - entity_preview
    - entity_cache_cleanup
    - workspace_version_diff
    - data_collection_version_diff
  `uuid: str GET`

    The unique identifier of the job.

    Example: 123e4567-e89b-12d3-a456-426614174000